Tutorial
===============================

You can find a basic tutorial of gtrace in its `GitHub repository <https://github.com/asoy01/gtrace>`_.

You can download the gtrace source tree by::

    git clone https://github.com/asoy01/gtrace.git

Or the direct link to the tutorial file is here: https://github.com/asoy01/gtrace/blob/master/Manuals/Tutorial/gtrace-tutorial.ipynb

Or you can find it directly here:

.. toctree::
   :maxdepth: 1

   tutorial/gtrace-tutorial

---------------
